==> sslexplorer-0.2.13-src.tar.gz: sslexplorer-0.2.13/sslexplorer-community-web-forwards/src/com/sslexplorer/webforwards/WebForwardPlugin.java <==
/*
 *  SSL-Explorer
 *
 *  Copyright (C) 2003-2006 3SP LTD. All Rights Reserved
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
			
package com.sslexplorer.webforwards;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.sslexplorer.agent.DefaultAgentManager;
import com.sslexplorer.boot.ContextHolder;
import com.sslexplorer.core.CoreMenuTree;
import com.sslexplorer.core.CoreServlet;
import com.sslexplorer.core.CoreUtil;
import com.sslexplorer.core.MenuItem;
import com.sslexplorer.core.PageTaskMenuTree;
import com.sslexplorer.extensions.ExtensionException;
import com.sslexplorer.extensions.types.DefaultPlugin;
import com.sslexplorer.navigation.MenuTree;
import com.sslexplorer.navigation.NavigationManager;
import com.sslexplorer.policyframework.Permission;
import com.sslexplorer.policyframework.PolicyConstants;
import com.sslexplorer.policyframework.PolicyDatabase;
import com.sslexplorer.policyframework.PolicyDatabaseFactory;
import com.sslexplorer.policyframework.PolicyUtil;
import com.sslexplorer.policyframework.ResourceType;
import com.sslexplorer.policyframework.itemactions.AddToFavoritesAction;
import com.sslexplorer.policyframework.itemactions.CloneResourceAction;
import com.sslexplorer.policyframework.itemactions.EditResourceAction;
import com.sslexplorer.policyframework.itemactions.RemoveFromFavoritesAction;
import com.sslexplorer.policyframework.itemactions.RemoveResourceAction;
import com.sslexplorer.replacementproxy.ReplacementProxyMethodHandler;
import com.sslexplorer.reverseproxy.ReverseProxyMethodHandler;
import com.sslexplorer.security.SessionInfo;
import com.sslexplorer.table.TableItemActionMenuTree;

/**
 * Plugin implementation thats the <i>Network Places</i> feature.
 * 
 * @author James D Robinson <a href="mailto:james@3sp.com">&lt;james@3sp.com&gt;</a>
 */
public class WebForwardPlugin extends DefaultPlugin {

	/**
	 * Web Forward resource type ID
	 */
	public final static int WEBFORWARD_RESOURCE_TYPE_ID = 0;

	/**
	 * Web Forward resource type
	 */
	public final static ResourceType WEBFORWARD_RESOURCE_TYPE = new WebForwardResourceType();

	/**
	 * Extension bundle ID
	 */
	public static final String BUNDLE_ID = "sslexplorer-community-web-forwards";

	final static Log log = LogFactory.getLog(WebForwardPlugin.class);

	/**
	 * Message resources key (resource bundle id)
	 */
	public static final String MESSAGE_RESOURCES_KEY = "webForwards";

	/**
	 * Constructor.
	 */
	public WebForwardPlugin() {
		super("/WEB-INF/sslexplorer-community-web-forwards-tiles-defs.xml", true);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.sslexplorer.plugin.DefaultPlugin#startPlugin()
	 */
	public void activatePlugin() throws ExtensionException {
		super.activatePlugin();
		try {
			initDatabase();
			initPolicyFramework();
			initTableItemActions();
			initMainMenu();
			initPageTasks();
			initService();
			initTagLib();
			CoreUtil.updateEventsTable(WebForwardEventConstants.class);
		} catch (Exception e) {
			throw new ExtensionException(ExtensionException.INTERNAL_ERROR, e);
		}
	}

	void initDatabase() throws Exception {
		WebForwardDatabaseFactory.getInstance().open(CoreServlet.getServlet(), this.getPluginDefinition());
	}

	void initPolicyFramework() throws Exception {
		PolicyDatabase pdb = PolicyDatabaseFactory.getInstance();
		// Web Forward
		pdb.registerResourceType(WEBFORWARD_RESOURCE_TYPE);
		WEBFORWARD_RESOURCE_TYPE.addPermission(PolicyConstants.PERM_CREATE_EDIT_AND_ASSIGN);
		WEBFORWARD_RESOURCE_TYPE.addPermission(PolicyConstants.PERM_EDIT_AND_ASSIGN);
		WEBFORWARD_RESOURCE_TYPE.addPermission(PolicyConstants.PERM_DELETE);
		WEBFORWARD_RESOURCE_TYPE.addPermission(PolicyConstants.PERM_ASSIGN);
	}

	void initTableItemActions() throws Exception {
		MenuTree tree = NavigationManager.getMenuTree(TableItemActionMenuTree.MENU_TABLE_ITEM_ACTION_MENU_TREE);
		// Web Forwards
		tree.addMenuItem(null, new MenuItem("webForward", "webForwards", null, 100, false, SessionInfo.ALL_CONTEXTS));
		tree.addMenuItem("webForward", new AddToFavoritesAction("webForwards"));
		tree.addMenuItem("webForward", new RemoveFromFavoritesAction("webForwards"));
		tree.addMenuItem("webForward", new RemoveResourceAction(SessionInfo.MANAGEMENT_CONSOLE_CONTEXT, "webForwards"));
		tree.addMenuItem("webForward", new EditResourceAction(SessionInfo.MANAGEMENT_CONSOLE_CONTEXT, "webForwards"));
		tree.addMenuItem("webForward", new CloneResourceAction(SessionInfo.MANAGEMENT_CONSOLE_CONTEXT, "webForwards"));
	}

	void initMainMenu() throws Exception {
		MenuTree tree = NavigationManager.getMenuTree(CoreMenuTree.MENU_ITEM_MENU_TREE);

		tree.addMenuItem("resources", new MenuItem("userWebForwards",
						"webForwards",
						"/showUserWebForwards.do",
						50,
						true,
						null,
						SessionInfo.USER_CONSOLE_CONTEXT,
						null,
						null,
						WEBFORWARD_RESOURCE_TYPE));

		tree.addMenuItem("globalResources", new MenuItem("managementWebForwards",
						"webForwards",
						"/showWebForwards.do",
						100,
						true,
						null,
						SessionInfo.MANAGEMENT_CONSOLE_CONTEXT,
						WEBFORWARD_RESOURCE_TYPE,
						new Permission[] { PolicyConstants.PERM_CREATE_EDIT_AND_ASSIGN,
							PolicyConstants.PERM_EDIT_AND_ASSIGN,
							PolicyConstants.PERM_DELETE,
							PolicyConstants.PERM_ASSIGN }) {
			public boolean isAvailable(int checkNavigationContext, SessionInfo info, HttpServletRequest request) {
				boolean available = super.isAvailable(checkNavigationContext, info, request);
				if (available) {
					try {
						PolicyUtil.checkPermissions(WEBFORWARD_RESOURCE_TYPE,
							new Permission[] { PolicyConstants.PERM_CREATE_EDIT_AND_ASSIGN,
								PolicyConstants.PERM_EDIT_AND_ASSIGN,
								PolicyConstants.PERM_DELETE,
								PolicyConstants.PERM_ASSIGN },
							request);
						available = true;
					} catch (Exception e1) {
						available = false;
					}
				}
				return available;
			}
		});

		tree.addMenuItem("configuration", new MenuItem("replacements",
						"webForwards",
						"/showReplacements.do",
						600,
						true,
						null,
						SessionInfo.MANAGEMENT_CONSOLE_CONTEXT,
						PolicyConstants.REPLACEMENTS_RESOURCE_TYPE,
						new Permission[] { PolicyConstants.PERM_CHANGE },
						null));
	}
	
	void initTagLib() {
		ContextHolder.getContext().setResourceAlias("/sslexplorer/taglibs/webforwards", "/WEB-INF/webforwards.tld");
	}

	void initPageTasks() throws Exception {
		MenuTree tree = NavigationManager.getMenuTree(PageTaskMenuTree.PAGE_TASK_MENU_TREE);
		tree.addMenuItem(null, new MenuItem("showWebForwards", null, null, 100, false, SessionInfo.MANAGEMENT_CONSOLE_CONTEXT));
        Permission[] permissions = new Permission[] { PolicyConstants.PERM_CREATE_EDIT_AND_ASSIGN };
        MenuItem menuItem = new MenuItem("createWebForward", "webForwards", "/webForwardTypeSelection.do", 100, true, "_self",
                        SessionInfo.MANAGEMENT_CONSOLE_CONTEXT, WEBFORWARD_RESOURCE_TYPE, permissions, null);
        tree.addMenuItem("showWebForwards", menuItem);
    }

	void initService() throws InstantiationException, IllegalAccessException {
		// Register CONNECT handler
		if (!ContextHolder.getContext().isSetupMode()) {
			ContextHolder.getContext().registerRequestHandler(new ReverseProxyMethodHandler());
			ContextHolder.getContext().registerRequestHandler(new ReplacementProxyMethodHandler());
		}
		DefaultAgentManager.getInstance().registerService(WebForwardService.class);
	}

	@Override
	public void stopPlugin() throws ExtensionException {
		super.stopPlugin();
		try {
			stopDatabase();
			stopPolicyFramework();
			removeTableItemActions();
			removeMainMenu();
			removePageTasks();
			stopService();
		} catch (Exception e) {
			throw new ExtensionException(ExtensionException.INTERNAL_ERROR, e, "Failed to start.");
		}
	}

	private void stopService() {
		// Register CONNECT handler
		if (!ContextHolder.getContext().isSetupMode()) {
			ContextHolder.getContext().deregisterRequestHandler(new ReverseProxyMethodHandler());
			ContextHolder.getContext().deregisterRequestHandler(new ReplacementProxyMethodHandler());
		}
	}

	private void removePageTasks() {
		MenuTree tree = NavigationManager.getMenuTree(PageTaskMenuTree.PAGE_TASK_MENU_TREE);
		tree.removeMenuItem("showWebForwards", "createTunneledWebForward");
		tree.removeMenuItem("showWebForwards", "createReplacementWebForward");
		tree.removeMenuItem("showWebForwards", "createReverseProxyWebForward");
	}

	private void removeMainMenu() {
		MenuTree tree = NavigationManager.getMenuTree(CoreMenuTree.MENU_ITEM_MENU_TREE);
		tree.removeMenuItem("resources", "userWebForwards");
		tree.removeMenuItem("globalResources", "managementWebForwards");
		tree.removeMenuItem("configuration", "replacements");
	}

	private void removeTableItemActions() {
		MenuTree tree = NavigationManager.getMenuTree(TableItemActionMenuTree.MENU_TABLE_ITEM_ACTION_MENU_TREE);
		tree.removeMenuItem("webForward", AddToFavoritesAction.TABLE_ITEM_ACTION_ID);
		tree.removeMenuItem("webForward", RemoveFromFavoritesAction.TABLE_ITEM_ACTION_ID);
		tree.removeMenuItem("webForward", RemoveResourceAction.TABLE_ITEM_ACTION_ID);
		tree.removeMenuItem("webForward", EditResourceAction.TABLE_ITEM_ACTION_ID);
	}

	private void stopPolicyFramework() throws Exception {
		PolicyDatabase pdb = PolicyDatabaseFactory.getInstance();
		pdb.deregisterResourceType(WEBFORWARD_RESOURCE_TYPE);
	}

	private void stopDatabase() throws Exception {
		WebForwardDatabaseFactory.getInstance().close();
	}
}

==> sslexplorer-0.2.15_01-src.tar.gz: sslexplorer-0.2.15_01/sslexplorer-community-web-forwards/src/com/sslexplorer/webforwards/WebForwardPlugin.java <==
/*
 *  SSL-Explorer
 *
 *  Copyright (C) 2003-2006 3SP LTD. All Rights Reserved
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2 of
 *  the License, or (at your option) any later version.
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public
 *  License along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
			
package com.sslexplorer.webforwards;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.sslexplorer.agent.DefaultAgentManager;
import com.sslexplorer.boot.ContextHolder;
import com.sslexplorer.core.CoreMenuTree;
import com.sslexplorer.core.CoreServlet;
import com.sslexplorer.core.CoreUtil;
import com.sslexplorer.core.MenuItem;
import com.sslexplorer.core.PageTaskMenuTree;
import com.sslexplorer.extensions.ExtensionException;
import com.sslexplorer.extensions.types.DefaultPlugin;
import com.sslexplorer.navigation.MenuTree;
import com.sslexplorer.navigation.NavigationManager;
import com.sslexplorer.policyframework.Permission;
import com.sslexplorer.policyframework.PolicyConstants;
import com.sslexplorer.policyframework.PolicyDatabase;
import com.sslexplorer.policyframework.PolicyDatabaseFactory;
import com.sslexplorer.policyframework.PolicyUtil;
import com.sslexplorer.policyframework.ResourceType;
import com.sslexplorer.policyframework.itemactions.AddToFavoritesAction;
import com.sslexplorer.policyframework.itemactions.CloneResourceAction;
import com.sslexplorer.policyframework.itemactions.EditResourceAction;
import com.sslexplorer.policyframework.itemactions.RemoveFromFavoritesAction;
import com.sslexplorer.policyframework.itemactions.RemoveResourceAction;
import com.sslexplorer.replacementproxy.ReplacementProxyMethodHandler;
import com.sslexplorer.reverseproxy.ReverseProxyMethodHandler;
import com.sslexplorer.security.SessionInfo;
import com.sslexplorer.table.TableItemActionMenuTree;

/**
 * Plugin implementation thats the <i>Network Places</i> feature.
 * 
 * @author James D Robinson <a href="mailto:james@3sp.com">&lt;james@3sp.com&gt;</a>
 */
public class WebForwardPlugin extends DefaultPlugin {

	/**
	 * Web Forward resource type ID
	 */
	public final static int WEBFORWARD_RESOURCE_TYPE_ID = 0;

	/**
	 * Web Forward resource type
	 */
	public final static ResourceType WEBFORWARD_RESOURCE_TYPE = new WebForwardResourceType();

	/**
	 * Extension bundle ID
	 */
	public static final String BUNDLE_ID = "sslexplorer-community-web-forwards";

	final static Log log = LogFactory.getLog(WebForwardPlugin.class);

	/**
	 * Message resources key (resource bundle id)
	 */
	public static final String MESSAGE_RESOURCES_KEY = "webForwards";

	/**
	 * Constructor.
	 */
	public WebForwardPlugin() {
		super("/WEB-INF/sslexplorer-community-web-forwards-tiles-defs.xml", true);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.sslexplorer.plugin.DefaultPlugin#startPlugin()
	 */
	public void activatePlugin() throws ExtensionException {
		super.activatePlugin();
		try {
			initDatabase();
			initPolicyFramework();
			initTableItemActions();
			initMainMenu();
			initPageTasks();
			initService();
			initTagLib();
			CoreUtil.updateEventsTable(WebForwardPlugin.MESSAGE_RESOURCES_KEY, WebForwardEventConstants.class);
		} catch (Exception e) {
			throw new ExtensionException(ExtensionException.INTERNAL_ERROR, e);
		}
	}

	void initDatabase() throws Exception {
		WebForwardDatabaseFactory.getInstance().open(CoreServlet.getServlet(), this.getPluginDefinition());
	}

	void initPolicyFramework() throws Exception {
		PolicyDatabase pdb = PolicyDatabaseFactory.getInstance();
		// Web Forward
		pdb.registerResourceType(WEBFORWARD_RESOURCE_TYPE);
		WEBFORWARD_RESOURCE_TYPE.addPermission(PolicyConstants.PERM_CREATE_EDIT_AND_ASSIGN);
		WEBFORWARD_RESOURCE_TYPE.addPermission(PolicyConstants.PERM_EDIT_AND_ASSIGN);
		WEBFORWARD_RESOURCE_TYPE.addPermission(PolicyConstants.PERM_DELETE);
		WEBFORWARD_RESOURCE_TYPE.addPermission(PolicyConstants.PERM_ASSIGN);
	}

	void initTableItemActions() throws Exception {
		MenuTree tree = NavigationManager.getMenuTree(TableItemActionMenuTree.MENU_TABLE_ITEM_ACTION_MENU_TREE);
		// Web Forwards
		tree.addMenuItem(null, new MenuItem("webForward", "webForwards", null, 100, false, SessionInfo.ALL_CONTEXTS));
		tree.addMenuItem("webForward", new AddToFavoritesAction("webForwards"));
		tree.addMenuItem("webForward", new RemoveFromFavoritesAction("webForwards"));
		tree.addMenuItem("webForward", new RemoveResourceAction(SessionInfo.MANAGEMENT_CONSOLE_CONTEXT, "webForwards"));
		tree.addMenuItem("webForward", new EditResourceAction(SessionInfo.MANAGEMENT_CONSOLE_CONTEXT, "webForwards"));
		tree.addMenuItem("webForward", new CloneResourceAction(SessionInfo.MANAGEMENT_CONSOLE_CONTEXT, "webForwards"));
	}

	void initMainMenu() throws Exception {
		MenuTree tree = NavigationManager.getMenuTree(CoreMenuTree.MENU_ITEM_MENU_TREE);

		tree.addMenuItem("resources", new MenuItem("userWebForwards",
						"webForwards",
						"/showUserWebForwards.do",
						50,
						true,
						null,
						SessionInfo.USER_CONSOLE_CONTEXT,
						null,
						null,
						WEBFORWARD_RESOURCE_TYPE));

		tree.addMenuItem("globalResources", new MenuItem("managementWebForwards",
						"webForwards",
						"/showWebForwards.do",
						100,
						true,
						null,
						SessionInfo.MANAGEMENT_CONSOLE_CONTEXT,
						WEBFORWARD_RESOURCE_TYPE,
						new Permission[] { PolicyConstants.PERM_CREATE_EDIT_AND_ASSIGN,
							PolicyConstants.PERM_EDIT_AND_ASSIGN,
							PolicyConstants.PERM_DELETE,
							PolicyConstants.PERM_ASSIGN }) {
			public boolean isAvailable(int checkNavigationContext, SessionInfo info, HttpServletRequest request) {
				boolean available = super.isAvailable(checkNavigationContext, info, request);
				if (available) {
					try {
						PolicyUtil.checkPermissions(WEBFORWARD_RESOURCE_TYPE,
							new Permission[] { PolicyConstants.PERM_CREATE_EDIT_AND_ASSIGN,
								PolicyConstants.PERM_EDIT_AND_ASSIGN,
								PolicyConstants.PERM_DELETE,
								PolicyConstants.PERM_ASSIGN },
							request);
						available = true;
					} catch (Exception e1) {
						available = false;
					}
				}
				return available;
			}
		});
	}
	
	void initTagLib() {
		ContextHolder.getContext().setResourceAlias("/sslexplorer/taglibs/webforwards", "/WEB-INF/webforwards.tld");
	}

	void initPageTasks() throws Exception {
		MenuTree tree = NavigationManager.getMenuTree(PageTaskMenuTree.PAGE_TASK_MENU_TREE);
		tree.addMenuItem(null, new MenuItem("showWebForwards", null, null, 100, false, SessionInfo.MANAGEMENT_CONSOLE_CONTEXT));
        Permission[] permissions = new Permission[] { PolicyConstants.PERM_CREATE_EDIT_AND_ASSIGN };
        MenuItem menuItem = new MenuItem("createWebForward", "webForwards", "/webForwardTypeSelection.do", 100, true, "_self",
                        SessionInfo.MANAGEMENT_CONSOLE_CONTEXT, WEBFORWARD_RESOURCE_TYPE, permissions, null);
        tree.addMenuItem("showWebForwards", menuItem); 
        tree.addMenuItem("showWebForwards", new MenuItem("replacements",
            "webForwards",
            "/showReplacements.do",
            600,
            true,
            null,
            SessionInfo.MANAGEMENT_CONSOLE_CONTEXT,
            PolicyConstants.REPLACEMENTS_RESOURCE_TYPE,
            new Permission[] { PolicyConstants.PERM_CHANGE },
            null));
    }

	void initService() throws InstantiationException, IllegalAccessException {
		// Register CONNECT handler
		if (!ContextHolder.getContext().isSetupMode()) {
			ContextHolder.getContext().registerRequestHandler(new ReverseProxyMethodHandler());
			ContextHolder.getContext().registerRequestHandler(new ReplacementProxyMethodHandler());
		}
		DefaultAgentManager.getInstance().registerService(WebForwardService.class);
	}

	@Override
	public void stopPlugin() throws ExtensionException {
		super.stopPlugin();
		try {
			stopDatabase();
			stopPolicyFramework();
			removeTableItemActions();
			removeMainMenu();
			removePageTasks();
			stopService();
		} catch (Exception e) {
			throw new ExtensionException(ExtensionException.INTERNAL_ERROR, e, "Failed to start.");
		}
	}

	private void stopService() {
		// Register CONNECT handler
		if (!ContextHolder.getContext().isSetupMode()) {
			ContextHolder.getContext().deregisterRequestHandler(new ReverseProxyMethodHandler());
			ContextHolder.getContext().deregisterRequestHandler(new ReplacementProxyMethodHandler());
		}
	}

	private void removePageTasks() {
		MenuTree tree = NavigationManager.getMenuTree(PageTaskMenuTree.PAGE_TASK_MENU_TREE);
		tree.removeMenuItem("showWebForwards", "createTunneledWebForward");
		tree.removeMenuItem("showWebForwards", "createReplacementWebForward");
		tree.removeMenuItem("showWebForwards", "createReverseProxyWebForward");
	}

	private void removeMainMenu() {
		MenuTree tree = NavigationManager.getMenuTree(CoreMenuTree.MENU_ITEM_MENU_TREE);
		tree.removeMenuItem("resources", "userWebForwards");
		tree.removeMenuItem("globalResources", "managementWebForwards");
		tree.removeMenuItem("configuration", "replacements");
	}

	private void removeTableItemActions() {
		MenuTree tree = NavigationManager.getMenuTree(TableItemActionMenuTree.MENU_TABLE_ITEM_ACTION_MENU_TREE);
		tree.removeMenuItem("webForward", AddToFavoritesAction.TABLE_ITEM_ACTION_ID);
		tree.removeMenuItem("webForward", RemoveFromFavoritesAction.TABLE_ITEM_ACTION_ID);
		tree.removeMenuItem("webForward", RemoveResourceAction.TABLE_ITEM_ACTION_ID);
		tree.removeMenuItem("webForward", EditResourceAction.TABLE_ITEM_ACTION_ID);
	}

	private void stopPolicyFramework() throws Exception {
		PolicyDatabase pdb = PolicyDatabaseFactory.getInstance();
		pdb.deregisterResourceType(WEBFORWARD_RESOURCE_TYPE);
	}

	private void stopDatabase() throws Exception {
		WebForwardDatabaseFactory.getInstance().close();
	}
}
